@@ -14,8 +14,7 @@ impl ReadyBoardTracer {
     /// Create a new instance of the `Tracer`.
     pub fn new(path: Path) -> Self {
         let state = ReadyBoardState::new();
-        // TODO: Use the `Receiver`
-        let tracer = Tracer::new_push(state, path).0;
+        let tracer = Tracer::new_push(state, path);
         Self { tracer }
     }
 
